PseudotimeHeatmap
PseudotimeHeatmap.RdGenerate heatmap for Pseudotimecascade result
Arguments
- x
A gene expression matrix
- gl
Marked gene list
- annotation
Annotation matrix for genes in expression matrix
- show_sp
Logical; whether to overlay switch points on the heatmap (default: FALSE).
- switch_point
Named character vector of switch points for each gene (e.g.,
"12,35"). Names should matchrownames(x); values are comma-separated column indices.- ...
parameters passed to Heatmap